ChenSammi commented on PR #11744:
URL: https://github.com/apache/ozone/pull/11744#issuecomment-6409032558

   Random read and vector search benchmark
   Before the patch
   Random access: 2,564 rows/sec
   Vector search: 123.4 QPS
   nprobes=  1  QPS= 134.6  avg_latency=7.4ms
   nprobes=  4  QPS= 142.6  avg_latency=7.0ms
   nprobes=  8  QPS= 170.1  avg_latency=5.9ms
   nprobes= 16  QPS= 163.0  avg_latency=6.1ms
   nprobes= 32  QPS= 132.8  avg_latency=7.5ms
   
   
   After the patch
   Random access: 660 rows/sec
   Vector search: 69.2 QPS
   nprobes=  1  QPS=  82.1  avg_latency=12.2ms
   nprobes=  4  QPS=  81.4  avg_latency=12.3ms
   nprobes=  8  QPS=  84.3  avg_latency=11.9ms
   nprobes= 16  QPS=  84.6  avg_latency=11.8ms
   nprobes= 32  QPS=  74.8  avg_latency=13.4ms
   


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to